translate.convert.ts2po

Package translate :: Package convert :: Module ts2po |
[hide private]
[frames] | no frames]

# Module ts2po

source code

convert Qt Linguist (.ts) files to Gettext PO localization files

See: http://translate.sourceforge.net/wiki/toolkit/ts2po for examples and usage instructions

Classes | [hide private]
| ts2po

Functions | [hide private]
convertts(inputfile, outputfile, templates, duplicatestyle="msgctxt") reads in stdin using fromfileclass, converts using convertorclass, writes to stdout | source code
main(argv=None) | source code

Imports: po, ts